@@ -1,11 +1,9 @@
 package Catalyst::Plugin::Sitemap;
 BEGIN {
-  $Catalyst::Plugin::Sitemap::VERSION = '1.0.0';
+  $Catalyst::Plugin::Sitemap::AUTHORITY = 'cpan:YANICK';
 }
-
 # ABSTRACT: Sitemap support for Catalyst.
-
-
+$Catalyst::Plugin::Sitemap::VERSION = '1.0.1';
 use strict;
 use warnings;
 
@@ -23,8 +21,7 @@ has sitemap => (
 );
 
 sub sitemap_as_xml {
-    my $self = shift;
-    return $self->sitemap->as_xml->toString;
+    return $_[0]->sitemap->as_xml->toString;
 }
 
 sub _build_sitemap {
@@ -33,65 +30,63 @@ sub _build_sitemap {
     my $sitemap = WWW::Sitemap::XML->new;
 
     for my $controller ( map { $self->controller($_) } $self->controllers ) {
-      ACTION:
-        for my $a ( $controller->get_action_methods ) {
-
-            my $action = $controller->action_for( $a->name );
-
-            my $attr = $action->attributes->{Sitemap} or next ACTION;
-
-            die "more than one attribute 'Sitemap' for sub ",
-              $a->fully_qualified_name
-              if @$attr > 1;
-
-            my @attr = split /\s*(?:,|=>)\s*/, $attr->[0];
-
-            my %uri_params;
-
-            if ( @attr == 1 ) {
-                if ( $attr[0] eq '*' ) {
-                    my $sitemap_method = $action->name . "_sitemap";
-
-                    if ( $controller->can($sitemap_method) ) {
-                        $controller->$sitemap_method( $self, $sitemap );
-                        next ACTION;
-                    }
-                }
-
-                if ( $attr[0] + 0 > 0 ) {
-
-                    # it's a number
-                    $uri_params{priority} = $attr[0];
-                }
-
-            }
-            elsif ( @attr > 0 ) {
-                %uri_params = @attr;
-            }
-
-            $uri_params{loc} = $self->uri_for_action( $action->private_path );
-
-            $sitemap->add(%uri_params);
+        for my $action ( $controller->get_action_methods ) {
+            $self->_add_controller_action_to_sitemap( $sitemap, $controller, $action );
         }
-
     }
 
     return $sitemap;
 }
 
+sub _add_controller_action_to_sitemap {
+    my( $self, $sitemap, $controller, $act ) = @_;
+
+    my $action = $controller->action_for($act->name);
+
+    my $attr = $action->attributes->{Sitemap} or return;
+
+    die "more than one attribute 'Sitemap' for sub ", $act->fully_qualified_name
+        if @$attr > 1;
+
+    my @attr = split /\s*(?:,|=>)\s*/, $attr->[0];
+
+    my %uri_params;
+
+    if ( @attr == 1 ) {
+        if ( $attr[0] eq '*' ) {
+            my $sitemap_method = $action->name . "_sitemap";
+
+            return $controller->$sitemap_method( $self, $sitemap )
+                if  $controller->can($sitemap_method);
+        }
+        elsif ( $attr[0] + 0 > 0 ) { # it's a number
+            $uri_params{priority} = $attr[0];
+        }
+    }
+    elsif ( @attr > 0 ) {
+        %uri_params = @attr;
+    }
+
+    $uri_params{loc} = $self->uri_for_action( $action->private_path );
+
+    $sitemap->add(%uri_params);
+}
+
 1;
 
-
+__END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Catalyst::Plugin::Sitemap - Sitemap support for Catalyst.
 
 =head1 VERSION
 
-version 1.0.0
+version 1.0.1
 
 =head1 SYNOPSIS
 
@@ -225,7 +220,7 @@ Original module that this plugin was using under the hood.
 Similar plugin for the L<Dancer> framework, which inspired
 C<Catalyst::Plugin::Sitemap>. 
 
-=item http://babyl.dyndns.org/techblog/entry/catalyst-plugin-sitemap
+=item L<http://babyl.dyndns.org/techblog/entry/catalyst-plugin-sitemap>
 
 Blog article introducing C<Catalyst::Plugin::Sitemap>.
 
@@ -233,7 +228,7 @@ Blog article introducing C<Catalyst::Plugin::Sitemap>.
 
 =head1 AUTHOR
 
-Yanick Champoux <yanick@babyl.dyndns.org>
+Yanick Champoux <yanick@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
@@ -243,6 +238,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
